ProSHADE: Namespace Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

### - m -

- MapManipulationTask() : ProSHADE_internal_tasks
- MapOverlayTask() : ProSHADE_internal_tasks
- missingAxisHeight() : ProSHADE_internal_symmetry
- moveMapByFourier() : ProSHADE_internal_mapManip
- moveMapByIndices() : ProSHADE_internal_mapManip
- movePDBForMapCalc() : ProSHADE_internal_mapManip
- multiplyGroupElementMatrices() : ProSHADE_internal_maths
- multiplyTwoSquareMatrices() : ProSHADE_internal_maths
- myRound() : ProSHADE_internal_mapManip